@@ -351,10 +351,21 @@ void __fastcall TMainF::GUI_Configure()
     //Configure theme
     ConfigTheme();
 
-    //Set monospaced font to Cascadia Mono SemiBold if available on current system
-    if (Screen->Fonts->IndexOf("Cascadia Mono SemiBold") != -1) {
+    //Set monospaced font to preferred font if available on current system
+    System::UnicodeString fontName;
+    if (Prefs->Config(__T("Language"))==__T("ja"))
+        fontName = "MS Gothic";
+    else
+    if (Prefs->Config(__T("Language"))==__T("ko"))
+        fontName = "Malgun Gothic";
+    else
+    if (Prefs->Config(__T("Language"))==__T("zh-CN") || Prefs->Config(__T("Language"))==__T("zh-HK") || Prefs->Config(__T("Language"))==__T("zh-TW"))
+        fontName = "NSimSun";
+    else
+        fontName = "Cascadia Mono SemiBold";
+    if (Screen->Fonts->IndexOf(fontName) != -1) {
         TFont* MonoFont = new TFont;
-        MonoFont->Name = "Cascadia Mono SemiBold";
+        MonoFont->Name = fontName;
         MonoFont->Size = 10;
         Page_Text_Text->Font = MonoFont;
         Page_Custom_Text->Font = MonoFont;
@@ -399,8 +410,9 @@ void __fastcall TMainF::GUI_Configure()
     M_Options_ShowMenu->Checked=Prefs->Config(__T("ShowMenu")).To_int32s();
     M_Options_CloseAllAuto->Checked=Prefs->Config(__T("CloseAllAuto")).To_int32s();
 
-    //Toolbar
-    ToolBar->Visible=M_Options_ShowToolBar->Checked;
+    //Toolbar and Menu
+    M_Options_ShowToolBarClick(nullptr);
+    M_Options_ShowMenuClick(nullptr);
 
     // FFmpeg
     #ifndef MEDIAINFOGUI_PLUGIN_NO
@@ -972,14 +984,16 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     //Text
     else if (Page==Page_Text)
     {
-        if (M_Debug_Details50->Checked)
-            I->Option_Static(__T("Inform"), __T("Details;0.5"));
-        else if (M_Debug_Details90->Checked)
-            I->Option_Static(__T("Inform"), __T("Details;0.9"));
-        else if (M_Debug_Details100->Checked)
-            I->Option_Static(__T("Inform"), __T("Details;1"));
-        else
-            I->Option_Static(__T("Inform"));
+        I->Option_Static(__T("Inform"));
+
+        if (M_Debug_TraceLevel0->Checked)
+            I->Option_Static(__T("Trace_Level"), __T("0"));
+        else if (M_Debug_TraceLevel50->Checked)
+            I->Option_Static(__T("Trace_Level"), __T("0.5"));
+        else if (M_Debug_TraceLevel90->Checked)
+            I->Option_Static(__T("Trace_Level"), __T("0.9"));
+        else if (M_Debug_TraceLevel100->Checked)
+            I->Option_Static(__T("Trace_Level"), __T("1"));
 
         if (!Prefs->Config(__T("InformVersion")).empty())
             I->Option_Static(__T("Inform_Version"), Prefs->Config(__T("InformVersion")));
@@ -1622,7 +1636,7 @@ void __fastcall TMainF::M_Options_ShowMenuClick(TObject *Sender)
         MainMenu->Items->Items[Pos]->Visible=Visible;
     ToolBar_View_ShowMenu->Visible=!Visible;
 
-    if (!M_Options_ShowToolBar->Checked)
+    if (!M_Options_ShowMenu->Checked && !M_Options_ShowToolBar->Checked)
     {
         M_Options_ShowToolBar->Checked=true;
         M_Options_ShowToolBarClick(NULL);
